AIChatView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AIChatView
Constructors
- AIChatView({Key? key, required AIChatviewController aIChatViewController, Widget emptyState = const SizedBox(), VoidCallback? onSendTap, Widget? aiTypingWidget, Widget? aiWidget, Widget? textFieldOtherWidget, Widget? leftPanelWidget})
-
aIChatViewControlleris required.const
Properties
- aIChatViewController → AIChatviewController
-
aIChatViewController is required.
final
- aiTypingWidget → Widget?
-
aiTypingWidget Widget to display when AI is still get data
final
- aiWidget → Widget?
-
aiWidgetThis widget is placed below each AI text. Used this when you intend to put a thumbs-up, report or other widget below each AI text
final
- emptyState → Widget
-
emptyState is the default state that would be displayed if there is not chat
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leftPanelWidget → Widget?
-
leftPanelWidgetThis is for placing widget at the left side of the TextformField for added functionalities
final
- onSendTap → VoidCallback?
-
onSendTap Callback when message is sent by user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textFieldOtherWidget → Widget?
-
textFieldOtherWidgetThis widget is placed within the textfield. Used when you intend to put other functionalities like mic
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited