AIChatView constructor

const AIChatView({
  1. Key? key,
  2. required AIChatviewController aIChatViewController,
  3. Widget emptyState = const SizedBox(),
  4. VoidCallback? onSendTap,
  5. Widget? aiTypingWidget,
  6. Widget? aiWidget,
  7. Widget? textFieldOtherWidget,
  8. Widget? leftPanelWidget,
})

aIChatViewController is required.

emptyState is the default state that would be displayed if there is not chat

aiTypingWidget Widget to display when AI is still get data

aiWidgetThis widget is placed below each AI text. Used this when you intend to put a thumbs-up, report or other widget below each AI text

aiWidgetThis widget is placed below each AI text. Used this when you intend to put a thumbs-up, report or other widget below each AI text

textFieldOtherWidgetThis widget is placed within the textfield. Used when you intend to put other functionalities like mic

leftPanelWidgetThis is for placing widget at the left side of the TextformField for added functionalities

Implementation

const AIChatView({
  super.key,
  required this.aIChatViewController,
  this.emptyState = const SizedBox(),
  this.onSendTap,
  this.aiTypingWidget,
  this.aiWidget,
  this.textFieldOtherWidget,
  this.leftPanelWidget,
});