textFieldOtherWidget property
textFieldOtherWidgetThis widget is placed within the textfield. Used when you intend to put other functionalities like mic
Implementation
final Widget? textFieldOtherWidget;
textFieldOtherWidgetThis widget is placed within the textfield. Used when you intend to put other functionalities like mic
final Widget? textFieldOtherWidget;