TextFieldDecoration class

Constructors

TextFieldDecoration({int maxLines = 4, int minLines = 1, String hintText = 'Message...', Color hintStyleColor = hintTextStyle})

Properties

hashCode int
The hash code for this object.
no setterinherited
hintStyleColor Color
final
hintText String
final
maxLines int
final
minLines int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited