AIChatView constructor
const
AIChatView({
- Key? key,
- required AIChatviewController aIChatViewController,
- Widget emptyState = const SizedBox(),
- VoidCallback? onSendTap,
- Widget? aiTypingWidget,
- Widget? aiWidget,
- Widget? textFieldOtherWidget,
- Widget? leftPanelWidget,
aIChatViewController is required.
emptyState is the default state that would be displayed if there is not chat
aiTypingWidget Widget to display when AI is still get data
aiWidgetThis widget is placed below each AI text. Used this when you intend to put a thumbs-up, report or other widget below each AI text
aiWidgetThis widget is placed below each AI text. Used this when you intend to put a thumbs-up, report or other widget below each AI text
textFieldOtherWidgetThis widget is placed within the textfield. Used when you intend to put other functionalities like mic
leftPanelWidgetThis is for placing widget at the left side of the TextformField for added functionalities
Implementation
const AIChatView({
super.key,
required this.aIChatViewController,
this.emptyState = const SizedBox(),
this.onSendTap,
this.aiTypingWidget,
this.aiWidget,
this.textFieldOtherWidget,
this.leftPanelWidget,
});