TypewriterAnimatedConfiguration class
Configuration for Animated Typewriter functionality as in a chatbot.
Constructors
- TypewriterAnimatedConfiguration({Duration typingSpeed = const Duration(milliseconds: 10)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typingSpeed → Duration
-
typingSpeed is the By default it is set to 10 milliseconds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited